@@ -5,7 +5,7 @@
 # Author    : Chris Jones
 # Email     : crj341@student.bham.ac.uk
 # Date      : 26/06/2020
-# Version   : 0.3.0
+# Version   : 0.3.1
 
 import  numpy                   as      np
 import  plotly.graph_objects    as      go
@@ -1220,4 +1220,107 @@ class AFM:
                 xaxis_title_text='Adhesion (nN)',
                 yaxis_title_text='Modulus (MPa)'
             )
+        fig.show()
+
+    def adhesion_map(self,
+        x_cells = 10,
+        y_cells = 10,
+        x_scale = 10,
+        y_scale = 10
+    ):
+
+        x_pos = np.zeros(x_cells * y_cells)
+        y_pos = np.zeros(x_cells * y_cells)
+        adhesion = np.zeros(x_cells * y_cells)
+        modulus = np.zeros(x_cells * y_cells)
+        depth = np.zeros(x_cells * y_cells)
+
+        x_counter = 1
+        y_counter = 1
+        loop_counter = 0
+        updown = 1
+
+        j = 0
+
+        while j < x_cells * y_cells:
+
+            x_pos[j] = x_counter
+            y_pos[j] = y_counter
+            adhesion[j] = self.adhesion[j]
+            modulus[j] = self.modulus[j]
+            depth[j]= next(n for n in self.z_approach[:,j] if n == n)
+
+            loop_counter += 1
+
+            if loop_counter == x_cells:
+
+                y_counter += 1
+                j += 1
+
+                if j == x_cells * y_cells:
+                    break
+
+                x_pos[j] = x_counter
+                y_pos[j] = y_counter
+                adhesion[j] = self.adhesion[j]
+                modulus[j] = self.modulus[j]
+                depth[j]= next(n for n in self.z_approach[:,j] if n == n)
+
+                if updown == 1:
+                    updown = 2
+                    loop_counter = 1
+                elif updown == 2:
+                    updown = 1
+                    loop_counter = 1
+
+            if updown == 1:
+                x_counter += 1
+            elif updown == 2:
+                x_counter -= 1
+
+            j += 1
+
+        x_pos = x_pos * x_scale/x_cells
+        y_pos = y_pos * y_scale/y_cells
+        depth = depth - depth[0]
+
+        fig = go.Figure(data=go.Heatmap(
+                x = x_pos,
+                y = y_pos,
+                z = adhesion,
+                type = 'heatmap',
+                colorscale = 'YlOrBr',
+                colorbar=dict(title='Adhesion (nN)')
+                ))
+
+        fig.update_layout(yaxis = dict(scaleanchor = 'x'))
+        fig.update_layout(plot_bgcolor='rgba(0,0,0,0)')
+
+        axis_template = dict(
+                    showgrid = False, zeroline = False,
+                    linecolor = 'white', showticklabels = True,
+                    ticks = '' )
+
+        fig.update_layout(margin = dict(t=200,r=200,b=200,l=200),
+            xaxis = axis_template,
+            yaxis = axis_template,
+            showlegend = False,
+            width = 700, height = 700,
+            autosize = False,
+            xaxis_title="X Position (um)",
+            yaxis_title="Y Position (um)")
+
+        fig.update_layout(
+            xaxis = dict(
+                tickmode = 'linear',
+                tick0 = 0,
+                dtick = 1
+            ),
+                yaxis = dict(
+                tickmode = 'linear',
+                tick0 = 0,
+                dtick = 1
+            )
+        )
+
         fig.show()
\ No newline at end of file
